@@ -5,17 +5,16 @@ use warnings;
 use strict;
 use 5.010001;
 
-our $VERSION = '0.036';
+our $VERSION = '0.037';
 
 use Encode       qw( encode decode );
 use File::Find   qw( find );
 use Scalar::Util qw( looks_like_number );
 
-use DBI                qw();
-use Encode::Locale     qw();
-use Term::Choose       qw( choose );
-use Term::Choose::Util qw( util_readline );
-use Term::ReadKey      qw( ReadMode );
+use DBI                  qw();
+use Encode::Locale       qw();
+use Term::Choose         qw( choose );
+use Term::ReadLine::Tiny qw();
 
 sub CLEAR_SCREEN () { "\e[1;1H\e[0J" }
 
@@ -30,22 +29,23 @@ sub __get_connect_data {
     my ( $self, $db, $key ) = @_;
     my $db_driver = $self->{info}{db_driver};
     my $db_key = $db_driver . '_' . $db;
-    my $prompt = ucfirst( $key ) . ' :';
+    my $prompt = ucfirst( $key ) . ': ';
     my $env_key = 'DBI_' . uc( $key );
     return '' if $db_driver eq 'SQLite';
-    if ( $self->{opt}{db_host_port} ) {
+    if ( $self->{opt}{ask_host_port_per_db} ) {
         return $self->{info}{login}{$db_key}{$key} if defined $self->{info}{login}{$db_key}{$key};
         if ( length $self->{opt}{$db_key}{$key} ) {
             say $prompt . $self->{opt}{$db_key}{$key};
             return $self->{opt}{$db_key}{$key};
         }
+        my $tiny = Term::ReadLine::Tiny->new();
         # Readline
-        my $new = util_readline( $prompt, { default => $self->{opt}{$db_driver}{$key} } ); #
+        my $new = $tiny->readline( $prompt, { default => $self->{opt}{$db_driver}{$key} } ); #
         $self->{info}{login}{$db_key}{$key} = $new;
         return $new;
     }
     else {
-        return $ENV{$env_key}                 if $self->{opt}{'env_dbi_' . $key} && exists $ENV{$env_key};
+        return $ENV{$env_key}                 if $self->{opt}{'use_env_dbi_' . $key} && exists $ENV{$env_key};
         return $self->{opt}{$db_driver}{$key} if exists $self->{opt}{$db_driver}{$key} && length $self->{opt}{$db_driver}{$key};
     }
     return;
@@ -57,34 +57,26 @@ sub __get_user {
     my $db_driver = $self->{info}{db_driver};
     my $db_key = $db_driver . '_' . $db;
     return '' if $db_driver eq 'SQLite';
-    if ( $self->{opt}{db_user_pass} ) {
+    if ( $self->{opt}{ask_user_pass_per_db} ) {
         return $self->{info}{login}{$db_key}{user} if defined $self->{info}{login}{$db_key}{user};
         if ( length $self->{opt}{$db_key}{user} ) {
             say 'User :' . $self->{opt}{$db_key}{user};
             return $self->{opt}{$db_key}{user};
         }
+        my $tiny = Term::ReadLine::Tiny->new();
         # Readline
-        my $new;
-        if ( $^O eq 'MSWin32' ) {
-            print 'User: ';
-            ReadMode 1;
-            $new = <STDIN>;
-            ReadMode 0;
-            chomp $new;
-        }
-        else {
-            $new = util_readline( 'User: ', { default => $self->{opt}{$db_driver}{user} } ); #
-        }
+        my $new = $tiny->readline( 'User: ', { default => $self->{opt}{$db_driver}{user} } ); #
         $self->{info}{login}{$db_key}{user} = $new;
         return $new;
     }
     else {
         return $self->{info}{login}{$db_driver}{user} if defined $self->{info}{login}{$db_driver}{user};
-        return $ENV{DBI_USER}                         if $self->{opt}{env_dbi_user} && exists $ENV{DBI_USER};
+        return $ENV{DBI_USER}                         if $self->{opt}{use_env_dbi_user} && exists $ENV{DBI_USER};
         #return $self->{opt}{$db_key}{user}            if length $self->{opt}{$db_key}{user};
         return $self->{opt}{$db_driver}{user}         if exists $self->{opt}{$db_driver}{user} && length $self->{opt}{$db_driver}{user};
+        my $tiny = Term::ReadLine::Tiny->new();
         # Readline
-        my $new = util_readline( 'User: ' );
+        my $new = $tiny->readline( 'User: ' );
         $self->{info}{login}{$db_driver}{user} = $new;
         return $new;
     }
@@ -96,18 +88,20 @@ sub __get_password {
     my $db_driver = $self->{info}{db_driver};
     my $db_key = $db_driver . '_' . $db;
     return '' if $db_driver eq 'SQLite';
-    if ( $self->{opt}{db_user_pass} ) {
+    if ( $self->{opt}{ask_user_pass_per_db} ) {
         return $self->{info}{login}{$db_key}{$user}{passwd} if defined $self->{info}{login}{$db_key}{$user}{passwd};
+        my $tiny = Term::ReadLine::Tiny->new();
         # Readline
-        my $passwd = util_readline( 'Password: ', { no_echo => 1 } );
+        my $passwd = $tiny->readline( 'Password: ', { no_echo => 1 } );
         $self->{info}{login}{$db_key}{$user}{passwd} = $passwd;
         return $passwd;
     }
     else {
         return $self->{info}{login}{$db_driver}{$user}{passwd} if defined $self->{info}{login}{$db_driver}{$user}{passwd};
-        return $ENV{DBI_PASS}                                  if $self->{opt}{env_dbi_pass} && exists $ENV{DBI_PASS};
+        return $ENV{DBI_PASS}                                  if $self->{opt}{use_env_dbi_pass} && exists $ENV{DBI_PASS};
+        my $tiny = Term::ReadLine::Tiny->new();
         # Readline
-        my $passwd = util_readline( 'Password: ', { no_echo => 1 }  );
+        my $passwd = $tiny->readline( 'Password: ', { no_echo => 1 }  );
         $self->{info}{login}{$db_driver}{$user}{passwd} = $passwd;
         return $passwd;
     }
